# Automated Architecture Analysis

[![pipeline status](https://gitlab.uni-ulm.de/se/mbti/automated-architecture-analysis/badges/main/pipeline.svg)](https://gitlab.uni-ulm.de/se/mbti/automated-architecture-analysis/-/commits/main)
[![coverage report](https://gitlab.uni-ulm.de/se/mbti/automated-architecture-analysis/badges/main/coverage.svg)](https://gitlab.uni-ulm.de/se/mbti/automated-architecture-analysis/-/commits/main)
[![Latest Release](https://gitlab.uni-ulm.de/se/mbti/automated-architecture-analysis/-/badges/release.svg)](https://gitlab.uni-ulm.de/se/mbti/automated-architecture-analysis/-/releases)

You can find the official documentation for the Automated Architecture Analysis tool [here](https://gitlab.uni-ulm.de/api/v4/projects/6351/jobs/artifacts/main/download?job=build-html).
